"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const path_2 = __importDefault(require("path"));
const utils_sh_1 = require("@goldstack/utils-sh");
const unified_1 = __importDefault(require("unified"));
const remark_parse_1 = __importDefault(require("remark-parse"));
const gray_matter_1 = __importDefault(require("gray-matter"));
function fileToMarkdownTree(filePath) {
    const data = (0, gray_matter_1.default)((0, utils_sh_1.read)(filePath)).content;
    const tree = (0, unified_1.default)()
        .use(remark_parse_1.default)
        .parse(data);
    // eslint-disable-next-line @typescript-eslint/no-use-before-define
    return rehypeDocs({ filePath })(tree);
}
function rehypeDocs({ filePath }) {
    function visitInlineCode(node) {
        const value = node.value;
        if (value.startsWith('markdown:')) {
            const file = value.substr(9);
            const combinedPath = path_2.default.normalize((0, path_1.dirname)(filePath) + '/' + file);
            if (!fs_1.default.existsSync(combinedPath)) {
                throw Error(`Invalid fragment specified; no such file "${combinedPath}"`);
            }
            const tree = fileToMarkdownTree(combinedPath);
            try {
                node.children = tree.children;
                node.value = '';
                node.type = 'root';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
    }
    function visitLink(node) {
        if (node.children.length > 0 && node.children[0].value === '!embed') {
            const file = node.url;
            const path = (0, path_1.dirname)(filePath) + '/' + file;
            if (!fs_1.default.existsSync(path)) {
                throw Error(`Invalid fragment specified; no such file "${path}"`);
            }
            const tree = fileToMarkdownTree(path);
            try {
                node.children = tree.children;
                node.value = '';
                node.type = 'root';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
        if (node.children.length > 0 &&
            node.children[0].value &&
            node.children[0].value.indexOf('%') === 0) {
            node.value = `[Video: ${node.children[0].value.substring(1)}](${node.url})`;
            node.type = 'text';
        }
    }
    return function transformer(tree) {
        (0, unist_util_visit_1.default)(tree, 'inlineCode', visitInlineCode);
        (0, unist_util_visit_1.default)(tree, (node) => node.type === 'link', visitLink);
        return tree;
    };
}
exports.default = rehypeDocs;
//# sourceMappingURL=rehypeMarkdownToMarkdown.js.map